**To get the partner account information**

The following ``get-partner-account`` example gets information about your Sidewalk account that has the following ID. ::

    aws iotwireless get-partner-account \
        --partner-account-id "12345678901234" \
        --partner-type "Sidewalk" 

Output::

    {
        "Sidewalk": {
            "AmazonId": "12345678901234", 
            "Fingerprint": "a123b45c6d78e9f012a34cd5e6a7890b12c3d45e6f78a1b234c56d7e890a1234"
        }, 
        "AccountLinked": false
    }

For more information, see `Amazon Sidewalk Integration for AWS IoT Core <https://docs.aws.amazon.com/iot/latest/developerguide/iot-sidewalk.html>`__ in the *AWS IoT Developers Guide*.
